Versioned HDF5
==============

Versioned HDF5 provides a versioned abstraction on top of `h5py <https://www.h5py.org/>`__ .

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   quickstart
   installation
   performance
   reference
   design
   changelog
   releasing

Benchmarks
----------

Benchmarks for Versioned HDF5 are published `here
<https://quansight.github.io/versioned-hdf5-benchmarks/>`_.

Source
------

The source code is on `GitHub <https://github.com/Quansight/versioned-hdf5>`_.
The code is licensed under the `BSD License
<https://github.com/Quansight/versioned-hdf5/blob/master/LICENSE>`_.
